@@ -79,21 +79,26 @@ frametoLme <- structure(function# LME modeling
 ### \code{\link{groupedData}} object.
 } , ex=function() {
     
-    ##Multilevel data frame of tree-ring widths:
-    data(Prings05,envir = environment())
-    ## Radial increments measured on 2003:
-    data(Pradii03,envir = environment())    
-    ## Monthly precipitation sums and average temperatures:
-    data(PTclim05,envir = environment())
+    ##TRW chronology (mm) and inside-bark radii
+    data(Pchron,envir = environment())
     
-    ##Modeling TRW fluctuations:
-    mpin <- modelFrame(Prings05,
-                       sc.c = Pradii03,
-                       rf.t = 2003)
-    
-    ## Detrending the TRW fluctuations by fitting a (l)td-form model
+    ## Parameters of allometric model to compute Diameter at Breast
+    ## Height over bark (DBH, cm) from diameter inside bark (dib, cm)
+    ## and Total Tree Biomass (TTB, kg tree -1 ) from DBH (Lara
+    ## et. al. 2013):
+    biom_param <- c(2.87, 0.85, 0.05, 2.5)
+
+    ## Modeling tree-biomass fluctuations while accounting for
+    ## within-plot source variability (see defaults in "modelFrame"
+    ## function)
+    trwf <- modelFrame(Pchron,
+                       to = 'cm',
+                       MoreArgs = list(mp = c(2,1, biom_param)),
+                       log.t = FALSE,
+                       on.time = FALSE)
+    ## Detrending the fluctuations by fitting a (l)td-form model
     ## with Maximum-likelihood method (ML):
-    pdata <- mpin$'model'$'data'
+    pdata <- trwf$'model'$'data'
     rlme <- frametoLme(pdata,
                        form = 'tdForm',
                        method = 'ML',
