@@ -110,26 +110,24 @@ modelFrame <- structure(function #Dendroclimatic-fluctuations modeling
 ### {\link{groupedData}} object in \code{model}, and model call in
 ### \code{call}.
 } , ex=function() {
-        ##TRW chronology (mm) and inside-bark radii
+    ##TRW chronology (mm) and inside-bark radii
     data(Pchron,envir = environment())
-    data(Pradii03,envir = environment())
-    ## Tree-ring width fluctuations:
-    trwf <- modelFrame(Pchron,
-                       sc.c = Pradii03,
-                       rf.t = 2003,
-                       log.t = TRUE)
-    summary(trwf$'model')
+    
+    ## Parameters of allometric model to compute Diameter at Breast
+    ## Height over bark (DBH, cm) from diameter inside bark (dib, cm)
+    ## and Total Tree Biomass (TTB, kg tree -1 ) from DBH (Lara
+    ## et. al. 2013):
+    biom_param <- c(2.87, 0.85, 0.05, 2.5)
 
-    ## Tree-diameter fluctuations:
-    tdf <- modelFrame(Pchron,
-                       sc.c = Pradii03,
-                       rf.t = 2003,
-                      log.t = TRUE,
-                      MoreArgs = list(mp = c(pi,2)))
-    
-    summary(tdf$'model')
-    
-    
+    ## Modeling tree-biomass fluctuations while accounting for
+    ## within-plot source variability (see defaults in "modelFrame"
+    ## function)
+    trwf <- modelFrame(Pchron,
+                       to = 'cm',
+                       MoreArgs = list(mp = c(2,1, biom_param)),
+                       log.t = FALSE,
+                       on.time = FALSE)
+            
     ## Climatic records:
     data(Temp,envir = environment())
     data(Prec,envir = environment())
