@@ -16,15 +16,23 @@ plot.modelFrame <- structure(function #Plot modelFrame objects
              ...)
         ## A diagnostic Trellis plot.
 } , ex=function() {
-    ##TRW chronology (mm) and reference inside-bark radii (mm)
-    ##measured at 2003:
+    ##TRW chronology (mm) and inside-bark radii
     data(Pchron,envir = environment())
-    data(Pradii03,envir = environment())
-    ## Tree-ring width fluctuations:
+    
+    ## Parameters of allometric model to compute Diameter at Breast
+    ## Height over bark (DBH, cm) from diameter inside bark (dib, cm)
+    ## and Total Tree Biomass (TTB, kg tree -1 ) from DBH (Lara
+    ## et. al. 2013):
+    biom_param <- c(2.87, 0.85, 0.05, 2.5)
+
+    ## Modeling tree-biomass fluctuations while accounting for
+    ## within-plot source variability (see defaults in "modelFrame"
+    ## function)
     trwf <- modelFrame(Pchron,
-                       sc.c = Pradii03,
-                       rf.t = 2003,
-                       log.t = TRUE)
+                       to = 'cm',
+                       MoreArgs = list(mp = c(2,1, biom_param)),
+                       log.t = FALSE,
+                       on.time = FALSE)
     plot(trwf, grid = FALSE)
 
 })
